==> haskell-aws-0.21.1-86-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.21.1
id: aws-0.21.1-BZHfR8gRvn2AZApbJvaCWb
key: aws-0.21.1-BZHfR8gRvn2AZApbJvaCWb
license: BSD-3-Clause
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
author: Aristid Breitkreuz, contributors see README
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
abi: 0c6db6cc1544352b0cb7e0601869c582
exposed: True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
import-dirs: /usr/lib/ghc-8.6.5/site-local/aws-0.21.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/aws-0.21.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aws-0.21.1
hs-libraries: HSaws-0.21.1-BZHfR8gRvn2AZApbJvaCWb
depends:
    aeson-1.4.4.0-CNxP0F7FYeU7wjnur6PUp4
    attoparsec-0.13.2.3-G0AWAouFPeyAsmzjnpc0yX base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-7zYdD3kTvDlD1D30r2J6kg
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    byteable-0.1.1-9guyEXUUK503mzSnI32g2S bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    conduit-1.3.1.1-DEyzgVREq8JGnMpn8fab1M
    conduit-extra-1.3.4-JIlobFcahoC3AmSc1lNocv containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    data-default-0.7.1.1-8HXMPOzA2RVIe3SOVrAaAg directory-1.3.3.0
    exceptions-0.10.2-HDaOvlvHbPR767FjhdL1tt filepath-1.4.2.1
    http-client-tls-0.3.5.3-ZsziWEYBPOBejZdpVEY1K
    http-conduit-2.3.7.1-Hs0qV7EZ0p63nGpyBxx0uu
    http-types-0.12.3-9Oghevaq5FtBD8UlWmZNzU
    lifted-base-0.2.3.12-6sIyoywK5sSEK6qAF0Ssup
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    monad-control-1.0.2.3-8DH4P9dnphD9L0cGYZ8UHr mtl-2.2.2
    network-2.8.0.0-1DkaUVvVIsp8sj7KmlE9xl
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    resourcet-1.2.2-LNFC9oX9jZq9q4YtEcrXC
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    xml-conduit-1.8.0.1-1misKtaNKQR1NpeqdhP6Fd
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.21.1-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.21.1
id: aws-0.21.1-DyeRA2RO21WLddQLqxYIJV
key: aws-0.21.1-DyeRA2RO21WLddQLqxYIJV
license: BSD-3-Clause
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
author: Aristid Breitkreuz, contributors see README
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
abi: db97b2680b2fbb8cf97e1b0a520d1657
exposed: True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
import-dirs: /usr/lib/ghc-8.6.5/site-local/aws-0.21.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/aws-0.21.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aws-0.21.1
hs-libraries: HSaws-0.21.1-DyeRA2RO21WLddQLqxYIJV
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    byteable-0.1.1-9guyEXUUK503mzSnI32g2S bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    conduit-1.3.1.1-6wGhn7vdA3B6uXWcLIr87M
    conduit-extra-1.3.4-K6FXFWghk929uw0H6vW1f containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-client-tls-0.3.5.3-1Aiha9XpRrMDnWLpJT85yp
    http-conduit-2.3.7.1-B08ieaTirROJ2iGsVG2V8n
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    xml-conduit-1.8.0.1-HAoYQb3t87CG79SFMbPm26
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
